//************************************************************************
// T6963.H
//
// LCD Gre und Hardwaredefinitionen
//
// hk@holger-klabunde.de
// www.holger-klabunde.de
// 14.10.2003
// Compiler MCC18
//************************************************************************
#ifndef t6963_h
#define t6963_h

#define SLOW
#define FAST
#ifdef FAST
 #undef SLOW
#endif 

#define LCD_WIDTH	240  //Display Breite
#define LCD_HEIGHT	64   //Display Hhe

// !!! only use ONE of the definitions below !!!
#define PIXPERBYTE_6 //pin FONT of the display connected to +5V
                      //undef this if you use 8x8 builtin font of display
                
//#define PIXPERBYTE_8  //pin FONT of the display connected to GROUND
                      //undef this if you use 6x8 builtin font of display

#ifdef PIXPERBYTE_6       // 6 bits per character for builtin font
 #define PIXPERBYTE    6  // than also 6 pixel per byte for graphic
#endif

#ifdef PIXPERBYTE_8      // 8 bits per character for builtin font
 #define PIXPERBYTE    8 // than also 8 pixel per byte for graphic
#endif

#define BYTES_PER_ROW   LCD_WIDTH / PIXPERBYTE     // how many bytes per row on screen
#define DISPLAYBYTES    (unsigned int)(BYTES_PER_ROW * LCD_HEIGHT) // how many bytes for a screen

#define T_BASE  0 	//begin of textarea
#define T_END   (unsigned int)(T_BASE + ( BYTES_PER_ROW * LCD_HEIGHT / 8 )) //end of textarea

#define G_BASE  (unsigned int)0x0200            	// base address of first screen
#define G_END  	G_BASE+DISPLAYBYTES-1   // end adress of first screen
#define G_BASE1 G_BASE+DISPLAYBYTES     // base address of 2nd screen
#define G_END1 	G_BASE1+DISPLAYBYTES-1  // end adress of 2nd screen

#define T_WR	PORTCbits.RC5
#define T_CE	PORTCbits.RC2
#define T_RD	PORTCbits.RC1
#define T_CD	PORTCbits.RC0

//PORTC ist der Datenport
#define INIT_CONTROL_PINS() { TRISC&=0xD8; TRISB=0xFF; } //control pins to output

#define DATA_DIR_IN()  TRISB=0xFF; // set io-pins to inputs
#define DATA_DIR_OUT() TRISB=0x00; // set io-pins to outputs
#define READ_DATA()    PORTB	   // read from data port
#define WRITE_DATA(a)  PORTB=(a);  // write to data port


#ifdef FAST
#define WR_ON()  T_WR=1; NOP(); NOP();
#define WR_OFF() T_WR=0; NOP(); NOP();
#endif
#ifdef SLOW
#define WR_ON()  { T_WR=1; Delay100us(1); }
#define WR_OFF() { T_WR=0; Delay100us(1); }
#endif

#ifdef FAST
#define RD_ON()  T_RD=1; NOP(); NOP();
#define RD_OFF() T_RD=0; NOP(); NOP();
#endif
#ifdef SLOW
#define RD_ON()  { T_RD=1; Delay100us(1); }
#define RD_OFF() { T_RD=0; Delay100us(1); }
#endif

//You don't need CE ! Connect it to ground.
#ifdef FAST
//#define CE_ON()  T_CE=1; NOP(); NOP(); 
#define CE_ON()  T_CE=0; 
//#define CE_OFF() T_CE=0; NOP(); NOP();
#define CE_OFF() T_CE=0;
#endif
#ifdef SLOW
#define CE_ON()  { T_CE=1; Delay100us(1); }
#define CE_OFF() { T_CE=0; Delay100us(1); }
#endif

#ifdef FAST
#define CTRL()   T_CD=1; NOP(); NOP();
#define DATA()   T_CD=0; NOP(); NOP(); 
#endif
#ifdef SLOW
#define CTRL()   { T_CD=1; Delay100us(1); }
#define DATA()   { T_CD=0; Delay100us(1); }
#endif

//Prototypes
extern void CheckBusy(void);
extern unsigned char ReadDisplay(void);
extern void WriteData1(unsigned char, unsigned char);
extern void WriteData2(unsigned int, unsigned char);
extern void WriteData(unsigned char dat);
extern void WriteCommand(unsigned char command);
extern void SetPixel(unsigned char xpos, unsigned char ypos, unsigned char mode);
extern unsigned char GetPixel(unsigned char xpos, unsigned char ypos);
extern void SetGBaseLine(unsigned char line);
extern void SetPosition(unsigned char xpos, unsigned char ypos);
extern void DisplayOn(void);
extern void ClearScreen(void);
extern void ClearGScreen(unsigned int begin, unsigned int end);
extern void ClearTextScreen(void);
extern void FillScreen(void);
extern unsigned char ConvertText(unsigned char ch);
extern void LCDText(const rom char *txt, unsigned char xpos, unsigned char ypos);
extern void ShowHex(unsigned char dat);

#endif // t6963_h
